package java.awt;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.Serializable;

public class FlowLayout implements LayoutManager, Serializable
{
    public static final int LEFT = 0;
    public static final int CENTER = 1;
    public static final int RIGHT = 2;
    public static final int LEADING = 3;
    public static final int TRAILING = 4;
    int align;
    int newAlign;
    int hgap;
    int vgap;
    private boolean alignOnBaseline;
    private static final long serialVersionUID = -7262534875583282631L;
    private static final int currentSerialVersion = 1;
    private int serialVersionOnStream;
    
    public FlowLayout() {
        this(1, 5, 5);
    }
    
    public FlowLayout(int n) {
        this(n, 5, 5);
    }
    
    public FlowLayout(int alignment, int hgap, int vgap) {
        this.serialVersionOnStream = 1;
        this.hgap = hgap;
        this.vgap = vgap;
        this.setAlignment(alignment);
    }
    
    public int getAlignment() {
        return this.newAlign;
    }
    
    public void setAlignment(int n) {
        switch (this.newAlign = n) {
            case 3: {
                this.align = 0;
                break;
            }
            case 4: {
                this.align = 2;
                break;
            }
            default: {
                this.align = n;
                break;
            }
        }
    }
    
    public int getHgap() {
        return this.hgap;
    }
    
    public void setHgap(int hgap) {
        this.hgap = hgap;
    }
    
    public int getVgap() {
        return this.vgap;
    }
    
    public void setVgap(int vgap) {
        this.vgap = vgap;
    }
    
    public void setAlignOnBaseline(boolean alignOnBaseline) {
        this.alignOnBaseline = alignOnBaseline;
    }
    
    public boolean getAlignOnBaseline() {
        return this.alignOnBaseline;
    }
    
    @Override
    public void addLayoutComponent(String s, Component component) {
    }
    
    @Override
    public void removeLayoutComponent(Component component) {
    }
    
    @Override
    public Dimension preferredLayoutSize(Container container) {
        synchronized (container.getTreeLock()) {
            Dimension dimension = new Dimension(0, 0);
            int componentCount = container.getComponentCount();
            int n = 1;
            int alignOnBaseline = this.getAlignOnBaseline();
            int max = 0;
            int max2 = 0;
            for (int i = 0; i < componentCount; ++i) {
                Component component = container.getComponent(i);
                if (component.isVisible()) {
                    Dimension preferredSize = component.getPreferredSize();
                    dimension.height = Math.max(dimension.height, preferredSize.height);
                    if (n != 0) {
                        n = 0;
                    }
                    else {
                        dimension.width += this.hgap;
                    }
                    dimension.width += preferredSize.width;
                    if (!(alignOnBaseline == 0)) {
                        int baseline = component.getBaseline(preferredSize.width, preferredSize.height);
                        if (baseline >= 0) {
                            max = Math.max(max, baseline);
                            max2 = Math.max(max2, preferredSize.height - baseline);
                        }
                    }
                }
            }
            if (!(alignOnBaseline == 0)) {
                dimension.height = Math.max(max + max2, dimension.height);
            }
            Insets insets = container.getInsets();
            dimension.width += insets.left + insets.right + this.hgap * 2;
            dimension.height += insets.top + insets.bottom + this.vgap * 2;
            return dimension;
        }
    }
    
    @Override
    public Dimension minimumLayoutSize(Container container) {
        synchronized (container.getTreeLock()) {
            int alignOnBaseline = this.getAlignOnBaseline();
            Dimension dimension = new Dimension(0, 0);
            int componentCount = container.getComponentCount();
            int max = 0;
            int max2 = 0;
            int n = 1;
            for (int i = 0; i < componentCount; ++i) {
                Component component = container.getComponent(i);
                if (component.visible) {
                    Dimension minimumSize = component.getMinimumSize();
                    dimension.height = Math.max(dimension.height, minimumSize.height);
                    if (n != 0) {
                        n = 0;
                    }
                    else {
                        dimension.width += this.hgap;
                    }
                    dimension.width += minimumSize.width;
                    if (!(alignOnBaseline == 0)) {
                        int baseline = component.getBaseline(minimumSize.width, minimumSize.height);
                        if (baseline >= 0) {
                            max = Math.max(max, baseline);
                            max2 = Math.max(max2, dimension.height - baseline);
                        }
                    }
                }
            }
            if (!(alignOnBaseline == 0)) {
                dimension.height = Math.max(max + max2, dimension.height);
            }
            Insets insets = container.getInsets();
            dimension.width += insets.left + insets.right + this.hgap * 2;
            dimension.height += insets.top + insets.bottom + this.vgap * 2;
            return dimension;
        }
    }
    
    private int moveComponents(Container container, int n, int n2, int n3, int max, int i, int n4, boolean b, boolean b2, int[] array, int[] array2) {
        switch (this.newAlign) {
            case 0: {
                n += (b ? 0 : n3);
                break;
            }
            case 1: {
                n += n3 / 2;
                break;
            }
            case 2: {
                n += (b ? n3 : 0);
                break;
            }
            case 3: {
                break;
            }
            case 4: {
                n += n3;
                break;
            }
        }
        int max2 = 0;
        int max3 = 0;
        int n5 = 0;
        if (b2) {
            int max4 = 0;
            Component component;
            for (; i < n4; ++i) {
                component = container.getComponent(i);
                if (component.visible) {
                    if (array[i] >= 0) {
                        max2 = Math.max(max2, array[i]);
                        max4 = Math.max(max4, array2[i]);
                    }
                    else {
                        max3 = Math.max(component.getHeight(), max3);
                    }
                }
            }
            max = Math.max(max2 + max4, max3);
            n5 = (max - max2 - max4) / 2;
        }
        for (int j = i; j < n4; ++j) {
            Component component2 = container.getComponent(j);
            if (component2.isVisible()) {
                int n6;
                if (b2 && array[j] >= 0) {
                    n6 = n2 + n5 + max2 - array[j];
                }
                else {
                    n6 = n2 + (max - component2.height) / 2;
                }
                if (b) {
                    component2.setLocation(n, n6);
                }
                else {
                    component2.setLocation(container.width - n - component2.width, n6);
                }
                n += component2.width + this.hgap;
            }
        }
        return max;
    }
    
    @Override
    public void layoutContainer(Container container) {
        synchronized (container.getTreeLock()) {
            Insets insets = container.getInsets();
            int n = container.width - (insets.left + insets.right + this.hgap * 2);
            int componentCount = container.getComponentCount();
            int width = 0;
            int n2 = insets.top + this.vgap;
            int a = 0;
            int n3 = 0;
            int leftToRight = container.getComponentOrientation().isLeftToRight();
            int alignOnBaseline = this.getAlignOnBaseline();
            int[] array = null;
            int[] array2 = null;
            if (!(alignOnBaseline == 0)) {
                array = new int[componentCount];
                array2 = new int[componentCount];
            }
            for (int i = 0; i < componentCount; ++i) {
                Component component = container.getComponent(i);
                if (component.isVisible()) {
                    Dimension preferredSize = component.getPreferredSize();
                    component.setSize(preferredSize.width, preferredSize.height);
                    if (!(alignOnBaseline == 0)) {
                        int baseline = component.getBaseline(preferredSize.width, preferredSize.height);
                        if (baseline >= 0) {
                            array[i] = baseline;
                            array2[i] = preferredSize.height - baseline;
                        }
                        else {
                            array[i] = -1;
                        }
                    }
                    if (width == 0 || width + preferredSize.width <= n) {
                        if (width > 0) {
                            width += this.hgap;
                        }
                        width += preferredSize.width;
                        a = Math.max(a, preferredSize.height);
                    }
                    else {
                        int moveComponents = this.moveComponents(container, insets.left + this.hgap, n2, n - width, a, n3, i, (boolean)leftToRight, (boolean)alignOnBaseline, array, array2);
                        width = preferredSize.width;
                        n2 += this.vgap + moveComponents;
                        a = preferredSize.height;
                        n3 = i;
                    }
                }
            }
            this.moveComponents(container, insets.left + this.hgap, n2, n - width, a, n3, componentCount, (boolean)leftToRight, (boolean)alignOnBaseline, array, array2);
        }
    }
    
    private void readObject(ObjectInputStream objectInputStream) throws IOException, ClassNotFoundException {
        objectInputStream.defaultReadObject();
        if (this.serialVersionOnStream < 1) {
            this.setAlignment(this.align);
        }
        this.serialVersionOnStream = 1;
    }
    
    @Override
    public String toString() {
        String str = "";
        switch (this.align) {
            case 0: {
                str = ",align=left";
                break;
            }
            case 1: {
                str = ",align=center";
                break;
            }
            case 2: {
                str = ",align=right";
                break;
            }
            case 3: {
                str = ",align=leading";
                break;
            }
            case 4: {
                str = ",align=trailing";
                break;
            }
        }
        return this.getClass().getName() + "[hgap=" + this.hgap + ",vgap=" + this.vgap + str + "]";
    }
}
